==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiCore/QSaveFile_shell.h <==
#ifndef QSAVEFILE_SHELL_H
#define QSAVEFILE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtCore/qsavefile.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qfiledevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QSaveFile_shell : public QSaveFile, public QtJambiShellInterface
{
public:
    QSaveFile_shell(QObject* parent0 = nullptr);
    QSaveFile_shell(const QString& name0);
    QSaveFile_shell(const QString& name0, QObject* parent1);
    ~QSaveFile_shell() override;

    bool atEnd() const override;
    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QString fileName() const override;
    bool isSequential() const override;
    bool open(QIODevice::OpenMode flags0) override;
    QFileDevice::Permissions permissions() const override;
    qint64 pos() const override;
    qint64 readData(char* data0, qint64 maxlen1) override;
    qint64 readLineData(char* data0, qint64 maxlen1) override;
    bool reset() override;
    bool resize(qint64 sz0) override;
    bool seek(qint64 offset0) override;
    bool setPermissions(QFileDevice::Permissions permissionSpec0) override;
    qint64 size() const override;
    void timerEvent(QTimerEvent* event0) override;
    bool waitForBytesWritten(int msecs0) override;
    bool waitForReadyRead(int msecs0) override;
    qint64 writeData(const char* data0, qint64 len1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSaveFile_access : public QSaveFile
{
    jstring __qt_fileName(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_open_QIODevice_OpenMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint flags0);
    jint __qt_writeData_const_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jbyteArray data0);
};

#endif // QSAVEFILE_SHELL_H

==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiCore/QSaveFile_shell.h <==
#ifndef QSAVEFILE_SHELL_H
#define QSAVEFILE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCore/qsavefile.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qfiledevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QSaveFile_shell : public QSaveFile, public QtJambiShellInterface
{
public:
    QSaveFile_shell(QObject* parent0 = nullptr);
    QSaveFile_shell(const QString& name0);
    QSaveFile_shell(const QString& name0, QObject* parent1);
    ~QSaveFile_shell() override;

    bool atEnd() const override;
    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QString fileName() const override;
    bool isSequential() const override;
    bool open(QIODevice::OpenMode flags0) override;
    QFileDevice::Permissions permissions() const override;
    qint64 pos() const override;
    qint64 readData(char* data0, qint64 maxlen1) override;
    qint64 readLineData(char* data0, qint64 maxlen1) override;
    bool reset() override;
    bool resize(qint64 sz0) override;
    bool seek(qint64 offset0) override;
    bool setPermissions(QFileDevice::Permissions permissionSpec0) override;
    qint64 size() const override;
    void timerEvent(QTimerEvent* event0) override;
    bool waitForBytesWritten(int msecs0) override;
    bool waitForReadyRead(int msecs0) override;
    qint64 writeData(const char* data0, qint64 len1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSaveFile_access : public QSaveFile
{
    jstring __qt_fileName(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_open_QIODevice_OpenMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint flags0);
    jint __qt_writeData_const_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
};

#endif // QSAVEFILE_SHELL_H
